@@ -186,6 +186,30 @@ NetworkManager::Device::Type NetworkManager::DevicePrivate::convertType(uint typ
     case 22:
         // NM_DEVICE_TYPE_DUMMY
         return NetworkManager::Device::Dummy;
+    case 23:
+        // NM_DEVICE_TYPE_PPP
+        return NetworkManager::Device::Ppp;
+    case 24:
+        // NM_DEVICE_TYPE_OVS_INTERFACE
+        return NetworkManager::Device::OvsInterface;
+    case 25:
+        // NM_DEVICE_TYPE_OVS_PORT
+        return NetworkManager::Device::OvsPort;
+    case 26:
+        // NM_DEVICE_TYPE_OVS_BRIDGE
+        return NetworkManager::Device::OvsBridge;
+    case 27:
+        // NM_DEVICE_TYPE_WPAN
+        return NetworkManager::Device::Wpan;
+    case 28:
+        // NM_DEVICE_TYPE_6LOWPAN
+        return NetworkManager::Device::Lowpan;
+    case 29:
+        // NM_DEVICE_TYPE_NM_DEVICE_TYPE_WIREGUARD
+        return NetworkManager::Device::WireGuard;
+    case 30:
+        // NM_DEVICE_TYPE_WIFI_P2P
+        return NetworkManager::Device::WifiP2P;
     }
 
     return NetworkManager::Device::UnknownType;
@@ -279,9 +303,6 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
     } else if (property == QLatin1String("Interface")) {
         interfaceName = value.toString();
         Q_EMIT q->interfaceNameChanged();
-    } else if (property == QLatin1String("InterfaceFlags")) {
-        interfaceFlags = value.toUInt();
-        Q_EMIT q->interfaceFlagsChanged();
     } else if (property == QLatin1String("Ip4Address")) {
         ipV4Address = QHostAddress(ntohl(value.toUInt()));
         Q_EMIT q->ipV4AddressChanged();
@@ -504,12 +525,6 @@ bool NetworkManager::Device::managed() const
     return d->managed;
 }
 
-uint NetworkManager::Device::interfaceFlags() const
-{
-    Q_D(const Device);
-    return d->interfaceFlags;
-}
-
 uint NetworkManager::Device::mtu() const
 {
     Q_D(const Device);
